@@ -1,9 +1,13 @@
 import os
-import sys
+import inspect
+import tarfile
+
 import pytest
 
+import tarsafe
 from tarsafe import TarSafe, TarSafeException
 
+
 def test_bad_files():
     files = os.listdir("./test/data/bad")
     for file_ in files:
@@ -11,6 +15,7 @@ def test_bad_files():
             with TarSafe.open(f"./test/data/bad/{file_}", "r") as tar:
                 tar.extractall()
 
+
 def test_good_files():
     files = os.listdir("./test/data/good")
     for file_ in files:
@@ -19,6 +24,7 @@ def test_good_files():
         assert os.path.exists("./evil.sh")
         os.remove("./evil.sh")
 
+
 def test_good_file():
     files = os.listdir("./test/data/good")
     for file_ in files:
@@ -26,3 +32,11 @@ def test_good_file():
             tar.extract("evil.sh")
         assert os.path.exists("./evil.sh")
         os.remove("./evil.sh")
+
+
+def test_tarsafe_is_dropin_for_tarfile():
+    assert _get_exposed_members(tarfile) <= _get_exposed_members(tarsafe)
+
+
+def _get_exposed_members(module):
+    return set(module.__all__)
